Class: Openapi3Parser::NodeFactory::Fields::Reference::RecursiveResolvedInput

Inherits:
Object
  • Object
show all
Extended by:
Forwardable
Includes:
Enumerable
Defined in:
lib/openapi3_parser/node_factory/fields/reference.rb

Overview

Used in the place of a hash for resolved input so the value can be looked up at runtime avoiding a recursive loop.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(context) ⇒ RecursiveResolvedInput

Returns a new instance of RecursiveResolvedInput.



70
71
72
# File 'lib/openapi3_parser/node_factory/fields/reference.rb', line 70

def initialize(context)
  @context = context
end

Instance Attribute Details

#contextObject (readonly)

Returns the value of attribute context.



68
69
70
# File 'lib/openapi3_parser/node_factory/fields/reference.rb', line 68

def context
  @context
end

Instance Method Details

#resolved_inputObject



74
75
76
# File 'lib/openapi3_parser/node_factory/fields/reference.rb', line 74

def resolved_input
  context.resolved_input
end